## <p align='center'>paragon</p>

<p align='center'>
  A tiny command line benchmarking utility (and a python library!)
</p>

## Features [WIP]
- Statistical analysis
- Cool progress bars
- Python library
- Export results to various file formats

## Usage

You can install the command line utility via pip:

```bash
$ pip install paragon
```
